# python-clone-page (Working only linux)
A script for downloading complete web pages with assets

- [python-clone-page (Working only linux)](#python-clone-page-working-only-linux)
  - [Installation](#installation)
  - [Usage](#usage)
  - [Example](#example)

## Installation
```sh
pip install clone-page
```


## Usage
```sh
clone-page https://www.example.com/
```

## Example
![assets/example.png](https://raw.githubusercontent.com/jaytrairat/python-clone-page/main/assets/example.png)
